function [ result ] = Mie_cd( x,m, params )
% Calculate Mie coefficients based on the book:
% Craig F. Bohren, Donald R. Huffman, Absorption and scattering of light by small particles
% Chapter 4, John Wiley & Sons, 1983

nmax=10; % the approximation degree is set for this problem; 
         % for general problems this could be estimated automatically

cn = zeros(1,nmax);
dn = zeros(1,nmax);

mu1 = 1;
mu = 1;

for nn = 1:nmax
    % spherical Bessel
    jn = sphbes(nn,x, params);
    jnm = sphbes(nn,x*m, params);
    % spherical Hankel
    hn = sphhank(nn,x);
    % and their derivatives
    dhxn = d_x_sphhank(nn,x, params);
    djxn = d_x_sphbes(nn,x, params);
    djxmn = d_x_sphbes(nn,x*m, params);
    
    
    cnn = mu1 * jn * dhxn - mu1 * hn * djxn;
    cnd = mu1 * jnm * dhxn - mu * hn * djxmn;
    cn(nn) = cnn / cnd;
    
    dnn = mu1 * m * jn * dhxn - mu1 * m * hn * djxn;
    dnd = mu * m^2 * jnm * dhxn - mu1 * hn * djxmn;
    dn(nn) = dnn/dnd;
end

result = [cn; dn];

end

