clear all; close all; clc

% some constants
params.c_light = 299792458;         % [m/s]
params.l_unit= 1e-3;                % multiplier for [mm]
params.eps0 = 8.854187817*1e-12;    % [F/m]

% input data defined in Section 8.5.1 in IEC/IEEE 62704-4

params.E0 = 100;               % amplitude of incident wave [V/m]
%%%%%%%%%%%%%%%%
params.freq = 900e6;           % frequency of excitation [Hz]
params.eps_r = 41.5;           % relative permittivity of hom. sphere
params.sigma = 0.97;           % conductivity [S/m]
params.density = 1000;         % sphere density [kg/m3]
params.a = 100*params.l_unit;  % SPHERE radius [m]

% derived parameters
params.lambda = params.c_light/params.freq;             % wavelength in sorrounding media (vacuum)
params.k0 = 2*pi / params.lambda;                       % wavenumber in surrounding medium
params.x0 = params.k0 * params.a;
params.w = params.freq*2*pi;
params.eps_i =  params.sigma/params.w/params.eps0;      % imaginary part of permittivity
params.epsilon_r = (params.eps_r + 1i*params.eps_i);    % complex permittivity
params.m = sqrt(params.epsilon_r);                      % complex refrective index

% 3D Cartesian grid for volumetric integration and peak SAR search
params.resolution = 2*params.l_unit;              % grid resolution: 2mm

% cartesian grid - x/y/z
params.x_grid = -params.a:params.resolution:params.a;   
params.y_grid = -params.a:params.resolution:params.a;
params.z_grid = -params.a:params.resolution:params.a;

% limit for small argument / avoid division by zero
params.limit = 1E-10;
